@@ -1,6 +1,7 @@
 import json
 from calendar import timegm
 from datetime import datetime
+from json.encoder import encode_basestring_ascii, encode_basestring
 
 import django
 import jwt
@@ -11,13 +12,27 @@ from . import exceptions
 from .settings import jwt_settings
 
 
-def dateTimeEncoderDefault(self, obj):
-    if isinstance(obj, datetime.datetime):
-        return obj.strftime('%Y-%m-%d %H:%M:%S')
-    elif isinstance(obj, datetime.date):
-        return obj.strftime('%Y-%m-%d')
-    raise TypeError(f'Object of type {obj.__class__.__name__} '
-                    f'is not JSON serializable')
+def dateTimeEncoderEncode(self, o):
+    def encode(self, o):
+        # This is for extremely simple cases and benchmarks.
+        if isinstance(o, str):
+            if self.ensure_ascii:
+                return encode_basestring_ascii(o)
+            else:
+                return encode_basestring(o)
+        # This doesn't pass the iterator directly to ''.join() because the
+        # exceptions aren't as detailed.  The list call should be roughly
+        # equivalent to the PySequence_Fast that ''.join() would do.
+        chunks = self.iterencode(o, _one_shot=True)
+        if not isinstance(chunks, (list, tuple)):
+            chunks = list(chunks)
+        return ''.join(chunks)
+
+    if isinstance(o, datetime.datetime):
+        return o.strftime('%Y-%m-%d %H:%M:%S')
+    elif isinstance(o, datetime.date):
+        return o.strftime('%Y-%m-%d')
+    return encode(self, o)
 
 
 def jwt_payload(user, context=None):
@@ -40,7 +55,7 @@ def jwt_payload(user, context=None):
     if jwt_settings.JWT_ISSUER is not None:
         payload['iss'] = jwt_settings.JWT_ISSUER
 
-    json.JSONEncoder.default = dateTimeEncoderDefault
+    json.JSONEncoder.encode = dateTimeEncoderEncode
 
     return payload
 
